summaryrefslogtreecommitdiff
path: root/ace/SPIPE_Stream.cpp
diff options
context:
space:
mode:
authorcoryan <coryan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-09-17 03:22:08 +0000
committercoryan <coryan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-09-17 03:22:08 +0000
commitb0ea70644783428954166da5eac87ee6e2d3935e (patch)
tree0238291afd086b7903aa4cd2b8c1fadeeb266596 /ace/SPIPE_Stream.cpp
parente58ec4a7f71dfb4d7d9c7bc813eb7ae95d7c0855 (diff)
downloadATCD-b0ea70644783428954166da5eac87ee6e2d3935e.tar.gz
ChangeLogTag:Wed Sep 16 22:17:54 1998 Carlos O'Ryan <coryan@cs.wustl.edu>
Diffstat (limited to 'ace/SPIPE_Stream.cpp')
-rw-r--r--ace/SPIPE_Stream.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/ace/SPIPE_Stream.cpp b/ace/SPIPE_Stream.cpp
index 29a5433dd3d..1430fa8dfdb 100644
--- a/ace/SPIPE_Stream.cpp
+++ b/ace/SPIPE_Stream.cpp
@@ -36,11 +36,11 @@ ACE_SPIPE_Stream::send (size_t n, ...) const
// ACE_TRACE ("ACE_SPIPE_Stream::send");
va_list argp;
size_t total_tuples = n / 2;
- iovec *iovp;
+ ACE_IO_Vector_Base *iovp;
#if defined (ACE_HAS_ALLOCA)
- iovp = (iovec *) alloca (total_tuples * sizeof (iovec));
+ iovp = (ACE_IO_Vector_Base *) alloca (total_tuples * sizeof (ACE_IO_Vector_Base));
#else
- ACE_NEW_RETURN (iovp, iovec[total_tuples], -1);
+ ACE_NEW_RETURN (iovp, ACE_IO_Vector_Base[total_tuples], -1);
#endif /* !defined (ACE_HAS_ALLOCA) */
va_start (argp, n);
@@ -60,7 +60,7 @@ ACE_SPIPE_Stream::send (size_t n, ...) const
}
// This is basically an interface to ACE_OS::readv, that doesn't use
// the struct iovec explicitly. The ... can be passed as an arbitrary
// number of (char *ptr, int len) tuples. However, the count N is the
// *total* number of trailing arguments, *not* a couple of the number
// of tuple pairs!
@@ -71,11 +71,11 @@ ACE_SPIPE_Stream::recv (size_t n, ...) const
ACE_TRACE ("ACE_SPIPE_Stream::recv");
va_list argp;
size_t total_tuples = n / 2;
- iovec *iovp;
+ ACE_IO_Vector_Base *iovp;
#if defined (ACE_HAS_ALLOCA)
- iovp = (iovec *) alloca (total_tuples * sizeof (iovec));
+ iovp = (ACE_IO_Vector_Base *) alloca (total_tuples * sizeof (ACE_IO_Vector_Base));
#else
- ACE_NEW_RETURN (iovp, iovec[total_tuples], -1);
+ ACE_NEW_RETURN (iovp, ACE_IO_Vector_Base[total_tuples], -1);
#endif /* !defined (ACE_HAS_ALLOCA) */
va_start (argp, n);
@@ -60,7 +60,7 @@ ACE_SPIPE_Stream::send (size_t n, ...) const
}
// This is basically an interface to ACE_OS::readv, that doesn't use
-// the struct iovec explicitly. The ... can be passed as an arbitrary
+// the struct ACE_IO_Vector_Base explicitly. The ... can be passed as an arbitrary
// number of (char *ptr, int len) tuples. However, the count N is the
// *total* number of trailing arguments, *not* a couple of the number